/* Sweep

*/

#include <Servo.h>

Servo myservo;  // create servo object to control a servo

// definice pozicii
// nutno kalibrovat na konkretni servo
#define	POS_MIN			544     // pozice VLEVO (min.544)
#define	POS_MAX			2400    // pozice VPRAVO (max.2400)
#define POS_CENTER	(POS_MAX - POS_MIN)

#define	GRANULARITA	1     // cim mensi, tym plynulejsi pohyb (ale i pomalsi)
#define	SPOMALENIE	10    // cim mensi, tym rychlejsi pohyb

int pos = 0;     // premenna drziaca aktualnu poziciu
int pos_ciel;    // premenna drziaca cielovu poziciu
int led_C = 8;   // LED_C pin
int led_Z = 12;  // LED_Z pin
int tlacitko_Stuj = 6;    // TL Stuj pin
int tlacitko_Volno = 10;  // TL Volno pin

bool Aktual_TL_Stuj;
bool Aktual_TL_Volno;
bool Minuly_TL_Stuj = 0;
bool Minuly_TL_Volno = 0;

byte Aktual_TL = 0;  // aktualny stav tlacitok
byte Minuly_TL = 0;  // predosly stav tlacitok

bool JOG_MODE = false;  // JOG režim


void setup()
{
  myservo.attach(4,POS_MIN,POS_MAX);  // attaches the servo on pin 4 to the servo object
  pinMode(led_Z, OUTPUT);
  pinMode(tlacitko_Volno, INPUT);
  pinMode(led_C, OUTPUT);
  pinMode(tlacitko_Stuj, INPUT);
  digitalWrite(led_C, HIGH);

  // inicializace pozice serva (pseudo-homing)
  for (pos=POS_MAX ; pos >= POS_MIN; pos -= GRANULARITA) {
         myservo.writeMicroseconds(pos);
         delay(SPOMALENIE);
    }
  pos_ciel = pos;  // reset cilove pozice
}

void loop() {

Aktual_TL_Volno = digitalRead(tlacitko_Volno);  // nacteni aktualniho stavu tlacitka
Aktual_TL_Stuj = digitalRead(tlacitko_Stuj);    // nacteni aktualniho stavu tlacitka

Aktual_TL = Aktual_TL_Stuj | Aktual_TL_Volno << 1;  // agregace aktualniho stavu tlacitek do jedne promenne

// TLACITKA
// ak aktualny stav nezodpoveda stavu predoslemu → spracuj tlacitka
// 
if(Aktual_TL != Minuly_TL)
  {
    switch (Aktual_TL)
      {
        case 0x01:  // tlacitko "Stuj" (LEVA)
          if (Minuly_TL) break;       // debounce (dual-click)
          pos_ciel = POS_MIN;         // nastveni cilove pozice MIN/LEVA
          digitalWrite(led_C, HIGH);  // zmen hodnotu vystupu
          digitalWrite(led_Z, LOW);   // zmen hodnotu vystupu
          break;
        case 0x10:  // tlacitko "Volno" (PRAVA)
          if (Minuly_TL) break;       // debounce (dual-click)
          pos_ciel = POS_MAX;         // nastveni cilove pozice MAX/PRAVA
          digitalWrite(led_C, LOW);   // zmen hodnotu vystupu
          digitalWrite(led_Z, HIGH);  // zmen hodnotu vystupu
          break;
        case 0x11:  // tlacitka obe naraz (JOG)
          JOG_MODE = !JOG_MODE;       // prepnutie rezimu (NORMAL ↔ JOG)
          pos_ciel = pos;             // reset cilove pozice (STOP)
          digitalWrite(led_C, LOW);   // zmen hodnotu vystupu
          digitalWrite(led_Z, LOW);   // zmen hodnotu vystupu
          break;
        case 0x00:  // tlacitko ziadne (release)
          if (!JOG_MODE) break;       // ak nie sme v rezime JOG, ledka ostava svietit
          digitalWrite(led_C, LOW);   // zmen hodnotu vystupu
          digitalWrite(led_Z, LOW);   // zmen hodnotu vystupu
          break;
      }
    Minuly_TL = Aktual_TL;  // uloz aktualny stav tlacitok
  }

// POHYB / KROKOVANIE
// ak aktualna pozicia nezodpoveda cielovej → urob krok do ciela
// ak sme v rezime JOG a je stlacene tlacitko → urob krok do ciela
//
if(pos != pos_ciel && (!JOG_MODE || Aktual_TL))
  {
    pos = GRANULARITA == 1 || GRANULARITA < abs(pos - pos_ciel)
      ? pos + (pos_ciel > pos ? 1:-1) * GRANULARITA
      : pos_ciel;
    myservo.writeMicroseconds(pos);
    delay(SPOMALENIE);
  }

/*
if(Aktual_TL_Stuj == 1 && Minuly_TL_Stuj == 0)    // je-li ted stisknuto tlacitko 
  {                                             // a zaroven predtim nebylo 
    digitalWrite(led_C, HIGH); // zmen hodnotu vystupu
    digitalWrite(led_Z, LOW); // zmen hodnotu vystupu
         for (pos = POS_MAX; pos >= POS_MIN; pos -= GRANULARITA) { // goes from MAX to MIN position
         myservo.writeMicroseconds(pos);  // tell servo to go to position in variable 'pos'
         delay(SPOMALENIE);               // waits SPOMALENIE (ms) for the servo to reach the position
         }
  }

if(Aktual_TL_Volno == 1 && Minuly_TL_Volno == 0)    // je-li ted stisknuto tlacitko 
  {                                           			// a zaroven predtim nebylo 
    digitalWrite(led_Z, HIGH); // zmen hodnotu vystupu
    digitalWrite(led_C, LOW); // zmen hodnotu vystupu
        for (pos = POS_MIN; pos <= POS_CENTER; pos += GRANULARITA) { // goes from MIN to CENTER position
        // in steps of GRANULARITA
        myservo.writeMicroseconds(pos);          // tell servo to go to position in variable 'pos'
        delay(SPOMALENIE);                       // waits SPOMALENIE (ms) for the servo to reach the position
        }
        delay(2000);//počkej 2000ms
        for (pos = POS_CENTER; pos <= POS_MAX; pos += GRANULARITA) { // goes from CENTER to MAX position
        // in steps of GRANULARITA
        myservo.writeMicroseconds(pos);          // tell servo to go to position in variable 'pos'
        delay(SPOMALENIE);                       // waits SPOMALENIE (ms) for the servo to reach the position
        }
   }
*/

}  
